from copy_tests import *
from general_tests import *
from manager_tests import *
from page_tests import *
from permission_tests import *
from portal_tests import *
from portlets_tests import *
from registration_tests import *
from utils_tests import *

# from permissions.tests import *
# from workflows.tests import *
